@@ -1,6 +1,6 @@
 # -*- coding:utf-8 -*-
 
-# Copyright (c) 2009-2013 - Simon Conseil
+# Copyright (c) 2009-2014 - Simon Conseil
 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to
@@ -64,6 +64,11 @@ def generate_image(source, outname, settings, options=None):
     img = PILImage.open(source)
     original_format = img.format
 
+    if settings['copy_exif_data'] and settings['autorotate_images']:
+        logger.warning("The 'autorotate_images' and 'copy_exif_data' settings "
+                       "are not compatible because Sigal can't save the "
+                       "modified Orientation tag.")
+
     # Preserve EXIF data
     if settings['copy_exif_data'] and _has_exif_tags(img):
         if options is not None:
@@ -73,10 +78,11 @@ def generate_image(source, outname, settings, options=None):
         options['exif'] = img.info['exif']
 
     # Rotate the img, and catch IOError when PIL fails to read EXIF
-    try:
-        img = Transpose().process(img)
-    except (IOError, IndexError):
-        pass
+    if settings['autorotate_images']:
+        try:
+            img = Transpose().process(img)
+        except (IOError, IndexError):
+            pass
 
     # Resize the image
     if settings['img_processor']:
@@ -122,6 +128,7 @@ def generate_thumbnail(source, outname, box, fit=True, options=None):
 def process_image(filepath, outpath, settings):
     """Process one image: resize, create thumbnail."""
 
+    logger = logging.getLogger(__name__)
     filename = os.path.split(filepath)[1]
     outname = os.path.join(outpath, filename)
     ext = os.path.splitext(filename)[1]
@@ -133,7 +140,11 @@ def process_image(filepath, outpath, settings):
     else:
         options = {}
 
-    generate_image(filepath, outname, settings, options=options)
+    try:
+        generate_image(filepath, outname, settings, options=options)
+    except Exception as e:
+        logger.error('Failed to process image: %s', e)
+        return
 
     if settings['make_thumbs']:
         thumb_name = os.path.join(outpath, get_thumb(settings, filename))
@@ -203,7 +214,13 @@ def get_exif_tags(source):
         simple['focal'] = round(float(focal[0]) / focal[1])
 
     if 'ExposureTime' in data:
-        simple['exposure'] = '{0}/{1}'.format(*data['ExposureTime'])
+        if isinstance(data['ExposureTime'], tuple):
+            simple['exposure'] = '{0}/{1}'.format(*data['ExposureTime'])
+        elif isinstance(data['ExposureTime'], int):
+            simple['exposure'] = str(data['ExposureTime'])
+        else:
+            logger.warning('Unknown format for ExposureTime: %r (%s)',
+                           data['ExposureTime'], source)
 
     if 'ISOSpeedRatings' in data:
         simple['iso'] = data['ISOSpeedRatings']
@@ -212,8 +229,8 @@ def get_exif_tags(source):
         try:
             # Remove null bytes at the end if necessary
             date = data['DateTimeOriginal'].rsplit('\x00')[0]
-            dt = datetime.strptime(date, '%Y:%m:%d %H:%M:%S')
-            dt = dt.strftime('%A, %d. %B %Y')
+            simple['dateobj'] = datetime.strptime(date, '%Y:%m:%d %H:%M:%S')
+            dt = simple['dateobj'].strftime('%A, %d. %B %Y')
 
             if compat.PY2:
                 simple['datetime'] = dt.decode('utf8')
