@@ -1,6 +1,6 @@
 # -*- coding:utf-8 -*-
 
-# Copyright (c) 2009-2013 - Simon Conseil
+# Copyright (c) 2009-2014 - Simon Conseil
 # Copyright (c) 2013      - Christophe-Marie Duquesne
 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -21,19 +21,28 @@
 # FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 # IN THE SOFTWARE.
 
+import locale
 import logging
 import os
+from os.path import abspath, isabs, join, normpath
 from pprint import pformat
 
+from .compat import PY2
+
+
 _DEFAULT_CONFIG = {
     'adjust_options': {'color': 1.0, 'brightness': 1.0,
                        'contrast': 1.0, 'sharpness': 1.0},
-    'copy_exif_data': True,
+    'albums_sort_reverse': False,
+    'autorotate_images': True,
+    'colorbox_column_size': 4,
+    'copy_exif_data': False,
     'copyright': '',
     'destination': '_build',
     'files_to_copy': (),
     'google_analytics': '',
-    'img_ext_list': ['.jpg', '.jpeg', '.JPG', '.JPEG', '.png'],
+    'ignore_directories': [],
+    'ignore_files': [],
     'img_processor': 'ResizeToFit',
     'img_size': (640, 480),
     'index_in_url': False,
@@ -41,6 +50,8 @@ _DEFAULT_CONFIG = {
     'keep_orig': False,
     'links': '',
     'locale': '',
+    'medias_sort_attr': 'filename',
+    'medias_sort_reverse': False,
     'make_thumbs': True,
     'orig_dir': 'original',
     'orig_link': False,
@@ -51,12 +62,12 @@ _DEFAULT_CONFIG = {
     'thumb_prefix': '',
     'thumb_size': (200, 150),
     'thumb_suffix': '',
-    'vid_ext_list': ['.MOV', '.mov', '.avi', '.mp4', '.webm', '.ogv'],
     'video_size': (480, 360),
     'webm_options': ['-crf', '10', '-b:v', '1.6M',
                      '-qmin', '4', '-qmax', '63'],
     'write_html': True,
     'zip_gallery': False,
+    'zip_media_format': 'resized',
 }
 
 
@@ -77,17 +88,12 @@ def get_thumb(settings, filename):
 
     path, filen = os.path.split(filename)
     name, ext = os.path.splitext(filen)
-    if ext in settings['vid_ext_list']:
+
+    # FIXME: replace this list with Video.extensions
+    if ext in ('.MOV', '.mov', '.avi', '.mp4', '.webm', '.ogv'):
         ext = '.jpg'
-    return os.path.join(path, settings['thumb_dir'], settings['thumb_prefix'] +
-                        name + settings['thumb_suffix'] + ext)
-
-
-def get_orig(settings, filename):
-    """Return the path to the original image."""
-
-    path, filen = os.path.split(filename)
-    return os.path.join(path, settings['orig_dir'], filen)
+    return join(path, settings['thumb_dir'], settings['thumb_prefix'] +
+                name + settings['thumb_suffix'] + ext)
 
 
 def read_settings(filename=None):
@@ -112,16 +118,22 @@ def read_settings(filename=None):
         # Make the paths relative to the settings file
         paths = ['source', 'destination']
 
-        if os.path.isdir(os.path.join(settings_path, settings['theme'])):
+        if os.path.isdir(join(settings_path, settings['theme'])):
             paths.append('theme')
 
+        enc = locale.getpreferredencoding() if PY2 else None
+
         for p in paths:
             path = settings[p]
-            if path and not os.path.isabs(path):
-                settings[p] = os.path.abspath(os.path.normpath(os.path.join(
-                    settings_path, path)))
+            if path and not isabs(path):
+                settings[p] = abspath(normpath(join(settings_path, path)))
                 logger.debug("Rewrite %s : %s -> %s", p, path, settings[p])
 
+            # paths must to be unicode strings so that os.walk will return
+            # unicode dirnames and filenames
+            if PY2 and isinstance(settings[p], str):
+                settings[p] = settings[p].decode(enc)
+
     for key in ('img_size', 'thumb_size', 'video_size'):
         w, h = settings[key]
         if h > w:
