@@ -61,6 +61,23 @@ thumb_size = (280, 210)
 # Use symbolic links instead of copying the original images
 # orig_link = False
 
+# Reverse sort for albums
+# albums_sort_reverse = False
+
+# Attribute of Media objects which is used to sort medias. 'date' can be used
+# to sort with EXIF dates.
+# medias_sort_attr = 'filename'
+
+# Reverse sort for medias
+# medias_sort_reverse = False
+
+# Filter directories and files.
+# The settings take a list of patterns matched with the fnmatch module on the
+# path relative to the source directory:
+# http://docs.python.org/2/library/fnmatch.html
+ignore_directories = []
+ignore_files = []
+
 # Jpeg options
 # jpg_options = {'quality': 85,
 #                'optimize': True,
@@ -94,11 +111,18 @@ thumb_size = (280, 210)
 # google_analytics = ''
 
 # Set zip_gallery to either False or a file name. The final archive will
-# contain all original files.
+# contain all resized or original files (depending on `zip_media_format`).
 # zip_gallery = False   # False or 'archive.zip'
+# zip_media_format = 'resized'  # 'resized' or 'orig'
+
+# Autorotate images
+# Warning: this setting is not compatible with `copy_exif_data` (see below),
+# because Sigal can't save the modified Orientation tag (currently Pillow can't
+# write EXIF).
+# autorotate_images = True
 
 # If True, EXIF data from the original image is copied to the resized image
-# copy_exif_data = True
+# copy_exif_data = False
 
 # Specify a different locale. If set to '', the default locale is used.
 # locale = ''
@@ -107,3 +131,10 @@ thumb_size = (280, 210)
 # A symbolic link is used if ``orig_link`` is set to True (see above).
 # files_to_copy = (('extra/robots.txt', 'robots.txt'),
 #                  ('extra/favicon.ico', 'favicon.ico'),)
+
+# Colorbox theme config
+# The column size is given in number of column of the css grid of the Skeleton
+# framework which is used for this theme: http://www.getskeleton.com/#grid
+# Then the image size must be adapted to fit the column size.
+# The default is 4 columns which gives 220px. 3 columns gives 160px.
+# colorbox_column_size = 4
